@@ -1,6 +1,8 @@
-import commonjs from '../types';
+import type { RollupOptions } from 'rollup';
 
-const config: import('rollup').RollupOptions = {
+import commonjs from '..';
+
+const config: RollupOptions = {
   input: 'main.js',
   output: {
     file: 'bundle.js',
@@ -13,6 +15,7 @@ const config: import('rollup').RollupOptions = {
       exclude: ['node_modules/foo/**', 'node_modules/bar/**', /node_modules/],
       extensions: ['.js', '.coffee'],
       ignoreGlobal: false,
+      ignoreDynamicRequires: true,
       requireReturnsDefault: 'auto',
       sourceMap: false,
       transformMixedEsModules: false,
